#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const yargs_1 = __importDefault(require("yargs"));
const generate_1 = __importDefault(require("./../generate"));
const js_yaml_1 = __importDefault(require("js-yaml"));
const fs_1 = require("fs");
const util_1 = require("util");
const argv = yargs_1.default.options({
    config: { type: "string", default: "route-codegen.yml" },
    stacktrace: { type: "boolean", default: false },
    verbose: { type: "boolean", default: false },
}).argv;
const { config, stacktrace, verbose } = argv;
try {
    console.log("route-codegen START!");
    let ymlContent = fs_1.readFileSync(config, "utf8");
    if (typeof process !== "undefined" && "env" in process) {
        ymlContent = ymlContent.replace(/\$\{(.*)\}/g, (str, variable, index) => {
            var _a;
            util_1.log(`Replacing \${${variable}} with ${process.env[variable]}`);
            return (_a = process.env[variable]) !== null && _a !== void 0 ? _a : "";
        });
    }
    const configContent = js_yaml_1.default.safeLoad(ymlContent);
    generate_1.default(configContent, { verbose });
    console.log("route-codegen END!");
}
catch (e) {
    if (stacktrace) {
        console.log(e);
    }
    else {
        console.log(e.message);
    }
    process.exit(1);
}
//# sourceMappingURL=route-codegen.js.map