"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const config_1 = require("../config");
const generatorCore_1 = __importDefault(require("./generatorCore"));
const generatorDefault_1 = __importDefault(require("./generatorDefault"));
const generatorReactRouterV5_1 = __importDefault(require("./generatorReactRouterV5"));
const generatorNextJS_1 = __importDefault(require("./generatorNextJS"));
const generateTemplateFiles = (params) => {
    const { origin, routeName: originalRouteName, routePattern, destinationDir: originalDestinationDir, routingType, routeLinkOptions, importGenerateUrl, importRedirectServerSide, } = params;
    const routeNameString = originalRouteName.toString();
    const routeName = routeNameString[0].toUpperCase() + routeNameString.slice(1);
    const destinationDir = `${originalDestinationDir}/${originalRouteName}`;
    const [patternFile, patternNamedExports] = generatorCore_1.default.generatePatternFile({
        origin,
        routeName,
        routePattern,
        destinationDir,
        routingType,
    });
    const genUrlFile = generatorCore_1.default.generateUrlFile({
        importGenerateUrl,
        destinationDir,
        routeName,
        patternNamedExports,
    });
    const files = [patternFile, genUrlFile];
    switch (routingType) {
        case config_1.RoutingType.ReactRouterV5:
            if (routeLinkOptions.ReactRouterV5.generateLinkComponent) {
                const linkFile = generatorReactRouterV5_1.default.generateLinkFile({
                    routeName,
                    destinationDir,
                    routeLinkOption: routeLinkOptions.ReactRouterV5,
                    patternNamedExports,
                    importGenerateUrl,
                });
                files.push(linkFile);
            }
            if (routeLinkOptions.ReactRouterV5.generateUseParams && !!patternNamedExports.pathParamsInterfaceName) {
                const useParamsFile = generatorReactRouterV5_1.default.generateUseParamsFile({
                    routeName,
                    destinationDir,
                    patternName: patternNamedExports.patternName,
                    pathParamsFilename: patternNamedExports.filename,
                    pathParamsInterfaceName: patternNamedExports.pathParamsInterfaceName,
                });
                files.push(useParamsFile);
            }
            if (routeLinkOptions.ReactRouterV5.generateUseRedirect) {
                const useRedirectFile = generatorReactRouterV5_1.default.generateUseRedirectFile({
                    routeName,
                    destinationDir,
                    patternNamedExports,
                    importGenerateUrl,
                });
                files.push(useRedirectFile);
            }
            if (routeLinkOptions.ReactRouterV5.generateRedirectComponent) {
                const redirectFile = generatorReactRouterV5_1.default.generateRedirectFile({
                    patternNamedExports,
                    destinationDir,
                    importGenerateUrl,
                    routeName,
                });
                files.push(redirectFile);
            }
            break;
        case config_1.RoutingType.NextJS:
            if (routeLinkOptions.NextJS.generateLinkComponent) {
                const linkFile = generatorNextJS_1.default.generateLinkFile({
                    routeName,
                    destinationDir,
                    routeLinkOption: routeLinkOptions.NextJS,
                    patternNamedExports,
                    importGenerateUrl,
                });
                files.push(linkFile);
            }
            if (routeLinkOptions.NextJS.generateUseParams && !!patternNamedExports.pathParamsInterfaceNameNextJS) {
                const useParamsFileNextJS = generatorNextJS_1.default.generateUseParamsFile({
                    routeName,
                    routePattern,
                    destinationDir,
                    pathParamsFilename: patternNamedExports.filename,
                    pathParamsInterfaceName: patternNamedExports.pathParamsInterfaceNameNextJS,
                });
                files.push(useParamsFileNextJS);
            }
            if (routeLinkOptions.NextJS.generateUseRedirect) {
                const useRedirectFileNextJS = generatorNextJS_1.default.generateUseRedirectFile({
                    routeName,
                    destinationDir,
                    importGenerateUrl,
                    patternNamedExports,
                });
                files.push(useRedirectFileNextJS);
            }
            break;
        case config_1.RoutingType.Default:
            if (routeLinkOptions.Default.generateLinkComponent) {
                const linkFile = generatorDefault_1.default.generateLinkFile({
                    routeName,
                    destinationDir,
                    routeLinkOption: routeLinkOptions.Default,
                    patternNamedExports,
                    importGenerateUrl,
                });
                files.push(linkFile);
            }
            if (routeLinkOptions.Default.generateUseRedirect) {
                const useRedirectDefault = generatorDefault_1.default.generateUseRedirectFile({
                    routeName,
                    importGenerateUrl,
                    destinationDir,
                    patternNamedExports,
                });
                files.push(useRedirectDefault);
            }
            if (routeLinkOptions.Default.generateRedirectComponent) {
                const redirectFile = generatorDefault_1.default.generateRedirectFile({
                    routeName,
                    destinationDir,
                    importGenerateUrl,
                    patternNamedExports,
                    importRedirectServerSide,
                });
                files.push(redirectFile);
            }
            break;
    }
    return files;
};
exports.default = generateTemplateFiles;
//# sourceMappingURL=generateTemplateFiles.js.map