"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const printImport_1 = __importDefault(require("../../utils/printImport"));
const generateLinkFileDefault = (params) => {
    const { routeName, routeLinkOption, destinationDir, patternNamedExports: { patternName, pathParamsInterfaceName, filename: routePatternFilename, urlPartsInterfaceName, originName }, importGenerateUrl, } = params;
    const functionName = `Link${routeName}`;
    const defaultLinkPropsInterfaceName = `Link${routeName}Props`;
    const hasPathParams = !!pathParamsInterfaceName;
    const { hrefProp, importLink, linkComponent, linkPropsTemplate, linkPropsInterfaceName } = generateLinkInterface({
        defaultLinkPropsInterfaceName,
        urlPartsInterfaceName,
        routeLinkOption,
    });
    const template = `${printImport_1.default({ defaultImport: "React", from: "react" })}
  ${printImport_1.default(importGenerateUrl)}
  ${importLink ? printImport_1.default(importLink) : ""}
  ${printImport_1.default({
        namedImports: [{ name: patternName }, { name: urlPartsInterfaceName }, { name: originName }],
        from: `./${routePatternFilename}`,
    })}
  ${linkPropsTemplate}
  const ${functionName}: React.FunctionComponent<${linkPropsInterfaceName}> = ({ ${hasPathParams ? "path," : ""} query, origin, ...props }) => {
    const to = generateUrl(${patternName}, ${hasPathParams ? "path" : "{}"}, query, origin ?? ${originName});
    return <${linkComponent} {...props} ${hrefProp}={to} />;
  }
  export default ${functionName};
  `;
    const templateFile = {
        template,
        filename: functionName,
        extension: ".tsx",
        destinationDir,
    };
    return templateFile;
};
const generateLinkInterface = (params) => {
    const { routeLinkOption, defaultLinkPropsInterfaceName, urlPartsInterfaceName } = params;
    const { hrefProp, linkProps, importLink, linkComponent } = routeLinkOption;
    let linkPropsTemplate = `type ${defaultLinkPropsInterfaceName} = Omit<${linkProps}, '${hrefProp}'> & ${urlPartsInterfaceName}`;
    let linkPropsInterfaceName = defaultLinkPropsInterfaceName;
    if ("inlineLinkProps" in routeLinkOption && routeLinkOption.inlineLinkProps) {
        linkPropsTemplate = `${routeLinkOption.inlineLinkProps.template} & ${urlPartsInterfaceName}`;
        linkPropsInterfaceName = routeLinkOption.inlineLinkProps.linkProps;
    }
    return {
        importLink,
        linkPropsTemplate,
        linkComponent,
        hrefProp,
        linkPropsInterfaceName,
    };
};
exports.default = generateLinkFileDefault;
//# sourceMappingURL=generateLinkFileDefault.js.map