"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const printImport_1 = __importDefault(require("../../utils/printImport"));
const throwError_1 = __importDefault(require("../../utils/throwError"));
const generateLinkFileNextJS = (params) => {
    const { routeName, routeLinkOption, destinationDir, patternNamedExports: { filename: routePatternFilename, pathParamsInterfaceName, urlPartsInterfaceName, patternNameNextJS, possiblePathParamsVariableName, }, } = params;
    const functionName = `Link${routeName}`;
    const defaultLinkPropsInterfaceName = `Link${routeName}Props`;
    const hasPathParams = !!pathParamsInterfaceName;
    const { hrefProp, importLink, linkComponent, linkPropsTemplate, linkPropsInterfaceName } = generateLinkInterface({
        defaultLinkPropsInterfaceName,
        urlPartsInterfaceName,
        routeLinkOption,
    });
    if (!patternNameNextJS) {
        return throwError_1.default([], 'Missing "patternNameNextJS". This is most likely a problem with route-codegen.');
    }
    const namedImportsFromPatternFile = [{ name: urlPartsInterfaceName }, { name: patternNameNextJS }];
    let pathnameTemplate = `const pathname = ${patternNameNextJS};`;
    if (possiblePathParamsVariableName) {
        namedImportsFromPatternFile.push({ name: possiblePathParamsVariableName });
        pathnameTemplate = `const pathname = ${possiblePathParamsVariableName}.filter((key) => !(key in path)).reduce((prevPattern, suppliedParam) => prevPattern.replace(\`/[${"${suppliedParam"}}]\`, ""), ${patternNameNextJS});`;
    }
    const variablesTemplate = hasPathParams
        ? `const { path = {}, query = {}, ...rest } = props;`
        : `const { query = {}, ...rest } = props; const path = {};`;
    const template = `${printImport_1.default({ defaultImport: "React", from: "react" })}
  ${importLink ? printImport_1.default(importLink) : ""}
  ${printImport_1.default({ namedImports: namedImportsFromPatternFile, from: `./${routePatternFilename}` })}
  ${linkPropsTemplate}
  const ${functionName}: React.FunctionComponent<${linkPropsInterfaceName}> = props => {
    ${variablesTemplate}
    ${pathnameTemplate}
    const nextHref = {
      pathname: pathname,
      query: {
        ...path,
        ...query,
      },
    }
    return <${linkComponent} {...rest} ${hrefProp}={nextHref} />;
  }
  export default ${functionName};
  `;
    const templateFile = {
        template,
        filename: functionName,
        extension: ".tsx",
        destinationDir,
    };
    return templateFile;
};
const generateLinkInterface = (params) => {
    const { routeLinkOption, defaultLinkPropsInterfaceName, urlPartsInterfaceName } = params;
    const { hrefProp, linkProps, importLink, linkComponent } = routeLinkOption;
    const linkPropsTemplate = `type ${defaultLinkPropsInterfaceName} = Omit<${linkProps}, '${hrefProp}'> & ${urlPartsInterfaceName}`;
    const linkPropsInterfaceName = defaultLinkPropsInterfaceName;
    return {
        importLink,
        linkPropsTemplate,
        linkComponent,
        hrefProp,
        linkPropsInterfaceName,
    };
};
exports.default = generateLinkFileNextJS;
//# sourceMappingURL=generateLinkFileNextJS.js.map