"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path_to_regexp_1 = require("path-to-regexp");
const cache = {};
const cacheLimit = 10000;
let cacheCount = 0;
const compilePath = (path) => {
    if (cache[path]) {
        return cache[path];
    }
    const generator = path_to_regexp_1.compile(path);
    if (cacheCount < cacheLimit) {
        cache[path] = generator;
        cacheCount++;
    }
    return generator;
};
const generatePath = (path = "/", params = {}) => {
    return path === "/" ? path : compilePath(path)(params);
};
const generateQueryString = (urlQuery) => {
    if (!urlQuery) {
        return "";
    }
    const result = Object.entries(urlQuery)
        .filter((obj) => {
        const value = obj[1];
        return value !== undefined;
    })
        .reduce((prev, [key, value]) => prev.concat(key, "=", value, "&"), "?");
    return result.substring(0, result.length - 1);
};
const generateUrl = (pattern, inputParams, urlQuery, origin) => {
    return (origin !== null && origin !== void 0 ? origin : "") + generatePath(pattern, inputParams) + generateQueryString(urlQuery);
};
exports.default = generateUrl;
//# sourceMappingURL=generateUrl.js.map